#[non_exhaustive]pub enum VerificationErrorKind {
Configuration,
Transport,
Timeout,
InvalidResponse,
NotImplemented,
}Expand description
Broad category for failures that prevent a verification result.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Configuration
The adapter was configured incorrectly.
Transport
The provider could not be reached.
Timeout
The provider did not answer within the configured deadline.
InvalidResponse
The provider returned an unreadable or unsupported response.
NotImplemented
The provider adapter has not been implemented yet.